//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/View/Instrument/OffspecDetectorEditor.cpp
//! @brief     Implements class DetectorEditor
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#include "GUI/View/Instrument/OffspecDetectorEditor.h"
#include "GUI/Model/Device/InstrumentItems.h"
#include "GUI/Model/Device/SphericalDetectorItem.h"
#include "GUI/View/Instrument/SphericalDetectorForm.h"
#include "GUI/View/Tool/GroupBoxCollapser.h"
#include "GUI/View/Tool/WidgetUtils.h"
#include <QFormLayout>


OffspecDetectorEditor::OffspecDetectorEditor(QWidget* parent, OffspecInstrumentItem* instrument)
    : QGroupBox("Detector parameters", parent)
    , m_instrument(instrument)
{
    ASSERT(instrument);
    m_formLayout = new QFormLayout(this);

    auto* collapser = GroupBoxCollapser::installIntoGroupBox(this);
    collapser->setExpanded(instrument->isExpandDetector());
    connect(collapser, &GroupBoxCollapser::toggled, this,
            [instrument](bool b) { instrument->setExpandDetector(b); });

    createDetectorWidgets();
}

void OffspecDetectorEditor::createDetectorWidgets()
{
    while (m_formLayout->rowCount() > 1)
        m_formLayout->removeRow(1);

    SphericalDetectorItem* detectorItem = m_instrument->detectorItem();
    auto* editor = new SphericalDetectorForm(this, detectorItem);
    m_formLayout->addRow(editor);
    connect(editor, &SphericalDetectorForm::dataChanged, this, &OffspecDetectorEditor::dataChanged);
}
